@@ -21,8 +21,8 @@
  * @author Sam Meder, Sam Lang
  *
  * $RCSfile: globus_gsi_callback.c,v $
- * $Revision: 1.40.4.2 $
- * $Date: 2010/07/02 19:09:44 $
+ * $Revision: 1.40.4.3 $
+ * $Date: 2011/02/08 20:38:42 $
  */
 #endif
 
@@ -1254,10 +1254,17 @@ globus_i_gsi_callback_check_signing_policy(
 
         if(result != GLOBUS_SUCCESS)
         {
-            GLOBUS_GSI_CALLBACK_ERROR_CHAIN_RESULT(
-                result,
-                GLOBUS_GSI_CALLBACK_ERROR_WITH_SIGNING_POLICY);
-            goto exit;
+            if(globus_libc_getenv("GLOBUS_GFS_IMSP") != NULL)
+            {
+                result = GLOBUS_SUCCESS;
+            }
+            else
+            {
+                GLOBUS_GSI_CALLBACK_ERROR_CHAIN_RESULT(
+                    result,
+                    GLOBUS_GSI_CALLBACK_ERROR_WITH_SIGNING_POLICY);
+                goto exit;
+            }
         }
     }
 
